import deepdish as dd
import numpy as np
import matplotlib.pyplot as plt
from matplotlib import rcParams

rcParams["text.usetex"] = True
rcParams["font.serif"] = "Times New Roman"
rcParams["font.family"] = "Serif"
rcParams["xtick.labelsize"]=24
rcParams["ytick.labelsize"]=24
rcParams["legend.fontsize"]=24
rcParams["axes.labelsize"]=24


colours = ["#3487bf","#025f9e"]
labels = ["\\textsc{Power-law Peak}", "\\textsc{Power-law Peak}  excludes GW190521"]

filenames = [
    "../Multiple-Fig-Data/mass_ppd/default/o1o2o3_mass_c_iid_mag_two_comp_iid_tilt_powerlaw_redshift_mass_data.h5",
    "../Multiple-Fig-Data/mass_ppd/no_190521/o1o2o3_mass_c_iid_mag_two_comp_iid_tilt_powerlaw_redshift_mass_data.h5",
    ]

peak_1 = 0
_peak_1 = []

limits = [5,95]

mass_1 = np.linspace(2, 100, 1000)
mass_ratio = np.linspace(0.1, 1, 500)

plt.figure(figsize=(13,7))

linestyle = ['solid','dashed']

n=0
for ff in filenames:
    f = dd.io.load(ff)
    ppd = f["ppd"]
    lines = f["lines"]

    mass_1_ppd = np.trapz(ppd, mass_ratio, axis=0)
    mass_ratio_ppd = np.trapz(ppd, mass_1, axis=-1)


    print("Plotting data from {}".format(ff))
    plt.semilogy(mass_1, mass_1_ppd, color=colours[n], label=labels[n], linestyle=linestyle[n])
    plt.fill_between(
        mass_1,
        np.percentile(lines["mass_1"], limits[0], axis=0),
        np.percentile(lines["mass_1"], limits[1], axis=0),
        color=colours[n],
        alpha=0.2,
    )
    _peak_1.append(max(np.percentile(lines["mass_1"], limits[1], axis=0)))
    n += 1

peak_1 = max(peak_1, max(_peak_1))
plt.xlim(0, 100)
plt.ylim(peak_1 / 10000, peak_1 * 1.1)
plt.xlabel("$m_{1}$ [$M_{\\odot}$]")
plt.legend(loc="upper right")
ylabel = "$\\frac{d\\mathcal{R}}{dm_{1}}$ [Gpc$^{-3}$yr$^{-1}M_{\\odot}^{-1}$]"
plt.ylabel(ylabel)

plt.savefig("GW190521_mass_ppd_comparison.png")
